HTTP and Pagination
===================

REST client helpers, pagination primitives, transport abstractions, and retry
support.

.. autosummary::
   :toctree: generated

   etlplus.api
   etlplus.api.endpoint_client
   etlplus.api.pagination
   etlplus.api.rate_limiting
